Lua_RankItem = class("Lua_RankItem", Lua_ListCell)
function Lua_RankItem:ctor(p)
	self:superCall("ctor", p, "RankItem_skin")
end

function Lua_RankItem:buildShowItem()
	self:superCall("buildShowItem")

	self.avatarItem = Lua_AvatarItem.new(self.content)
	self.avatarItem:setScale(0.8, 0.8, 1);
	self.avatarItem:setLocation(-147, 0, 0)
end

function Lua_RankItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose()
		self.avatarItem = nil
	end
	self:superCall("dispose")
end

function Lua_RankItem:setData(data)
	local rankVo = DataCenter.rankUtil:getRankConfig(DataCenter.rankData.curRankType)

	self.numTxt.text = data.rank
	self.nameTxt.text = data.player_show.name
	
	self.avatarItem:setRoleId(data.player_show.id)
	self.avatarItem:setRoleDressUp(data.player_show.dress_info)
	self.avatarItem:setRoleLevel(data.player_show.level)
	
	self.valueTxt:setEnable(true)
	self.valueTxt.pivotValue = 4
	self.valueTxt.alignmentValue = 4
	self.valueTxt:setLocation(230, -1.5, 0)
	if rankVo.type >= 4 and rankVo.type <= Lua_RankData.LIGHT_TOWER_TYPE then
		self.valueTxt.text = LanUtil.formateStr(202531, data.value)
	elseif rankVo.type == Lua_RankData.FIGHT_TYPE then
		self.valueTxt.pivotValue = 3
		self.valueTxt.alignmentValue = 3
		self.valueTxt:setLocation(150, -1.5, 0)
		self.valueTxt.text = spliceIconStr("number", "xui_zl1_number_10", 30, 32).." "..data.value
	elseif rankVo.type == Lua_RankData.MAIN_LINE_TYPE then
		local config1 = Lua_MainLineCheckpointConfigData.getConfig(data.value)
		if config1 then
			local config2 = Lua_MainLineChapterConfigData.getConfig(config1.chapter_id)
			self.valueTxt.text = config2.name..config1.name
		else
			self.valueTxt:setEnable(false)
		end
	elseif rankVo.type == Lua_RankData.KUNXUHOLYLAND_TYPE then
		self.valueTxt.text = LanUtil.formateStr(202536, data.value, data.sub_value, spliceIconStr("common_altas_1", "xui_common_label_06", 30, 29))
	else
		self.valueTxt.text = data.value
	end
end




















Lua_LeagueRankItem = class("Lua_LeagueRankItem", Lua_ListCell)
function Lua_LeagueRankItem:ctor(p)
	self:superCall("ctor", p, "LeagueRankItem_skin")
end

function Lua_LeagueRankItem:buildShowItem()
	self:superCall("buildShowItem")

	self.avatarItem = Lua_AvatarItem.new(self.content)
	self.avatarItem:setScale(0.8, 0.8, 1);
	self.avatarItem:setLocation(-147, 0, 0)
end

function Lua_LeagueRankItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose()
		self.avatarItem = nil
	end
	self:superCall("dispose")
end

function Lua_LeagueRankItem:setData(data)
	self.avatarItem:setLeagueId(data.league_id)
	self.avatarItem:setLeagueAvatarId(data.league_head, 2, 0.4)

	self.numTxt.text = data.rank
	self.nameTxt.text = data.league_name
	self.valueTxt.text = spliceIconStr("number", "xui_zl1_number_10", 30, 32).." "..data.league_force
end




















Lua_StarTrialRankItem = class("Lua_StarTrialRankItem", Lua_ListCell)
function Lua_StarTrialRankItem:ctor(p)
	self:superCall("ctor", p, "StarTrialRankItem_skin")
end

function Lua_StarTrialRankItem:buildShowItem()
	self:superCall("buildShowItem")

	self.avatarItem = Lua_AvatarItem.new(self.content)
	self.avatarItem:setScale(0.8, 0.8, 1);
	self.avatarItem:setLocation(-147, 0, 0)
end

function Lua_StarTrialRankItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose()
		self.avatarItem = nil
	end
	self:superCall("dispose")
end

function Lua_StarTrialRankItem:setData(data)
	self.numTxt.text = data.rank

	self.nameTxt.text = data.player_show.name
	self.avatarItem:setRoleId(data.player_show.id)
	self.avatarItem:setRoleDressUp(data.player_show.dress_info)
	self.avatarItem:setRoleLevel(data.player_show.level)

	self.starTxt.text = spliceIconStr("common_altas_1", "xui_common_label_06", 30, 29)..data.value
	if data.sub_value > 0 then
		local vo = DataCenter.starTrialUitl:getStageVo(data.sub_value)
		self.valueTxt.text = LanUtil.formateStr(201615, vo.chapter, vo.index)
	else
		self.valueTxt.text = nil
	end
end




















Lua_HeroRankItem = class("Lua_HeroRankItem", Lua_ListCell)
function Lua_HeroRankItem:ctor(p)
	self:superCall("ctor", p, "HeroRankItem_skin")
end

function Lua_HeroRankItem:buildShowItem()
	self:superCall("buildShowItem")

	self.avatarItem = Lua_AvatarItem.new(self.content)
	self.avatarItem:setScale(0.8, 0.8, 1);
	self.avatarItem:setLocation(-147, 0, 0)
	self.avatarItem:setAvatarBg("common_altas_3", "xui_common_widget_019")
end

function Lua_HeroRankItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose()
		self.avatarItem = nil
	end
	self:superCall("dispose")
end

function Lua_HeroRankItem:setData(data)
	self.numTxt.text = data.rank

	local config = Lua_HeroConfigData.getConfig(data.other_value)
	if config then
		self.avatarItem:setRoleId(data.player_show.id)
		self.avatarItem:setHeroAvatar(data.other_value)

		self.heroTxt.text = config.name
	else
		self.avatarItem:init()
		self.heroTxt.text = nil
	end
	self.nameTxt.text = data.player_show.name
	
	self.valueTxt.text = spliceIconStr("number", "xui_zl1_number_10", 30, 32).." "..data.value
end



















Lua_ChampionshipRankItem = class("Lua_ChampionshipRankItem", Lua_ListCell)
function Lua_ChampionshipRankItem:ctor(p)
	self:superCall("ctor", p, "ChampionshipRankItem_skin")
end

function Lua_ChampionshipRankItem:buildShowItem()
	self:superCall("buildShowItem")
	self.btnLike:addClickFuntion(self, self.onLikeClick)

	self.avatarItem = Lua_AvatarItem.new(self.content)
	self.avatarItem:setScale(0.8, 0.8, 1);
	self.avatarItem:setLocation(-147, 0, 0)
end

function Lua_ChampionshipRankItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose()
		self.avatarItem = nil
	end
	self.data = nil
	self:superCall("dispose")
end

function Lua_ChampionshipRankItem:setData(data)
	self.data = data

	self.numTxt.text = data.rank
	
	self.avatarItem:setRoleId(data.id, data.is_robot)
	self.avatarItem:setRoleDressUp(data.show_role.dress_info)
	self.avatarItem:setRoleLevel(data.show_role.level)

	self.nameTxt.text = data.show_role.name
	if strIsNullOrEmpty(data.show_role.league_name) then
		self.leagueTxt:setLangValue(202503)
	else
		self.leagueTxt.text = LanUtil.formateStr(202504, data.show_role.league_name)
	end
	self.valueTxt.text = data.score
	self.likeNumTxt.text = data.like_num

	if data.is_praised == 1 then
		self.btnLike:setAltas("rank_altas", "xui_phb_btn_3_p");
	else
		self.btnLike:setAltas("rank_altas", "xui_phb_btn_3_n");
	end
end
function Lua_ChampionshipRankItem:onLikeClick(go)
	if self.data == nil then
		return
	end
	if DataCenter.roleData:isMyself(self.data.id) then
		OperateAlert.showLangValue(540046)
		return
	end
	if DataCenter.championshipData.likeTimes <= 0 then
		OperateAlert.showLangValue(540044)
		return
	end
	if self.data.is_praised == 1 then
		OperateAlert.showLangValue(540045)
		return
	end
	Lua_ProxyManager.getProxy("Lua_ChampionshipProxy"):sLike(self.data.id, 2);
end